%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LSSLS subroutine
% Unconstrained linear problem
% (minimum norm solutions for over- or determined linear systems Ax = b)
%   
%   b:   qx1     matrix
%   A:   qxn     matrix, q > n
%   q:   dimension of function phi
%   n:   number of design variables
% 
% Note : When A is not square and \ is used for A\b, then Householder
% reflections are used to compute an orthogonal-triangular factorization. 
% 
%   A*P = Q*R
% 
% where P is a permutation, Q is orthogonal and R is upper triangular
% (see qr). The least squares solution X is computed with 
% 
%   X = P*(R\(Q'*B))
% 
% Jean-François Gauthier : 2007/07/11
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[u] = LSSLS(b,A,q,n,ODA)

u = A\b;

